@@ -1,6 +1,6 @@
 package Catmandu::XML::Transformer;
 #ABSTRACT: Utility module for XSLT processing
-our $VERSION = '0.11'; #VERSION
+our $VERSION = '0.12'; #VERSION
 
 use Catmandu::Sane;
 use Moo;
@@ -14,32 +14,64 @@ has stylesheet => (
     is       => 'ro',
     required => 1,
     coerce   => sub {
-        my $xslt = XML::LibXML->load_xml(location => $_[0], no_cdata=>1);
-        XML::LibXSLT->new()->parse_stylesheet($xslt);
+        [ 
+            map {
+                XML::LibXSLT->new()->parse_stylesheet(
+                    XML::LibXML->load_xml(location => $_, no_cdata=>1)
+                )
+            } (ref $_[0] // '' eq 'ARRAY' ? @{$_[0]} : $_[0])
+        ]
     }
 );
 
+has has_text_output => (
+    is      => 'lazy',
+    default => sub {
+        @{$_[0]->stylesheet} and $_[0]->stylesheet->[-1]->output_method eq 'text'
+    }
+);
+
+sub transform_dom {
+    my ($self, $dom) = @_;
+
+    foreach (@{$self->stylesheet}) {
+        $dom = $_->transform($dom);
+    }
+
+    return $dom;
+}
+
 sub transform {
     my ($self, $xml) = @_;
+    my $result;
 
     # DOM to DOM
     if (blessed $xml && $xml->isa('XML::LibXML::Document')) {
-        return $self->stylesheet->transform($xml);
+        $result = $self->transform_dom($xml);
+        unless ($self->has_text_output) {
+            return $result;
+        }
     # MicroXML to MicroXML
     } elsif (ref $xml) {
-        $xml = XML::Struct::Writer->new->write( $xml );
-        my $result = $self->stylesheet->transform( $xml );
-        return XML::Struct::Reader->new( from => $result )->readDocument;
+        $xml = XML::Struct::Writer->new->write($xml);
+        $result = $self->transform_dom($xml);
+        unless ($self->has_text_output) {
+            return XML::Struct::Reader->new( from => $result )->readDocument;
+        }
     # string to string
     } else {
         $xml = XML::LibXML->load_xml(string => $xml);
-        my $result = $self->stylesheet->transform($xml);
-        return $self->stylesheet->output_as_chars($result);
+        $result = $self->transform_dom($xml);
     }
 
-    return;
+    if ($result and $self->stylesheet->[-1]) {
+        return $self->stylesheet->[-1]->output_as_chars($result);
+    } else {
+        return $result;
+    }
 }
 
+
 1;
 
 __END__
@@ -54,7 +86,7 @@ Catmandu::XML::Transformer - Utility module for XSLT processing
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPISIS
 
@@ -64,6 +96,13 @@ version 0.11
     $xml_dom    = $transformer->transform( $xml_dom );
     $xml_struct = $transformer->transform( $xml_struct );
 
+=head1 CONFIGURATION
+
+=head1 stylesheet
+
+XSLT filename or array reference with multiple files to apply as transformation
+pipeline.
+
 =head1 AUTHOR
 
 Jakob Voß
